@@ -23,10 +23,12 @@ import math
 
 # hwrt modules
 # HandwrittenData is necessary because of pickle
-from hwrt.HandwrittenData import HandwrittenData  # pylint: disable=unused-import
+from hwrt import HandwrittenData
+sys.modules['HandwrittenData'] = HandwrittenData
 import hwrt.features as features
 import hwrt.geometry as geometry
 import hwrt.utils as utils
+import hwrt.data_analyzation_metrics as dam
 
 
 def sort_by_formula_id(raw_datasets):
@@ -113,35 +115,6 @@ def analyze_feature(raw_datasets, feature, basename="aspect_ratios"):
     csv_file.close()
 
 
-def analyze_creator(raw_datasets, filename="creator.csv"):
-    """Analyze who created most of the data."""
-
-    # prepare file
-    root = utils.get_project_root()
-    folder = os.path.join(root, "analyzation/")
-    workfilename = os.path.join(folder, filename)
-    open(workfilename, 'w').close()  # Truncate the file
-    write_file = open(workfilename, "a")
-    write_file.write("creatorid,nr of symbols\n")  # heading
-
-    print_data = defaultdict(int)
-    start_time = time.time()
-    for i, raw_dataset in enumerate(raw_datasets):
-        if i % 100 == 0 and i > 0:
-            utils.print_status(len(raw_datasets), i, start_time)
-        print_data[raw_dataset['handwriting'].user_id] += 1
-    print("\r100%"+"\033[K\n")
-    # Sort the data by highest value, descending
-    print_data = sorted(print_data.items(),
-                        key=lambda n: n[1],
-                        reverse=True)
-    # Write data to file
-    write_file.write("total,%i\n" % sum([value for _, value in print_data]))
-    for userid, value in print_data:
-        write_file.write("%i,%i\n" % (userid, value))
-    write_file.close()
-
-
 def analyze_instroke_speed(raw_datasets, filename="instroke_speed.csv"):
     """Analyze how fast the points were in pixel/ms."""
     # prepare file
@@ -428,11 +401,20 @@ def main(handwriting_datasets_file):
         logging.info("create %s...", filename)
         analyze_feature(raw_datasets, feat, filename)
 
-    logging.info("creator...")
-    analyze_creator(raw_datasets)
+    creator_metric = dam.Creator()
+    creator_metric(raw_datasets)
+
     analyze_instroke_speed(raw_datasets)
     analyze_distance_betwee_strokes(raw_datasets)
 
+    cfg = utils.get_project_configuration()
+    if 'data_analyzation_plugins' in cfg:
+        metrics = dam.get_metrics(cfg['data_analyzation_plugins'])
+
+    for metric in metrics:
+        logging.info("Start metric %s...", str(metric))
+        metric(raw_datasets)
+
 
 def get_parser():
     """Return the parser object for this script."""
